# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from anndb import core_pb2 as anndb_dot_core__pb2
from anndb import dataset_pb2 as anndb_dot_dataset__pb2


class DatasetManagerStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.List = channel.unary_stream(
        '/anndb_pb.DatasetManager/List',
        request_serializer=anndb_dot_core__pb2.EmptyMessage.SerializeToString,
        response_deserializer=anndb_dot_dataset__pb2.Dataset.FromString,
        )
    self.Get = channel.unary_unary(
        '/anndb_pb.DatasetManager/Get',
        request_serializer=anndb_dot_core__pb2.UUIDRequest.SerializeToString,
        response_deserializer=anndb_dot_dataset__pb2.Dataset.FromString,
        )
    self.Create = channel.unary_unary(
        '/anndb_pb.DatasetManager/Create',
        request_serializer=anndb_dot_dataset__pb2.Dataset.SerializeToString,
        response_deserializer=anndb_dot_dataset__pb2.Dataset.FromString,
        )
    self.Delete = channel.unary_unary(
        '/anndb_pb.DatasetManager/Delete',
        request_serializer=anndb_dot_core__pb2.UUIDRequest.SerializeToString,
        response_deserializer=anndb_dot_core__pb2.EmptyMessage.FromString,
        )


class DatasetManagerServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def List(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Get(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Create(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_DatasetManagerServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'List': grpc.unary_stream_rpc_method_handler(
          servicer.List,
          request_deserializer=anndb_dot_core__pb2.EmptyMessage.FromString,
          response_serializer=anndb_dot_dataset__pb2.Dataset.SerializeToString,
      ),
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=anndb_dot_core__pb2.UUIDRequest.FromString,
          response_serializer=anndb_dot_dataset__pb2.Dataset.SerializeToString,
      ),
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=anndb_dot_dataset__pb2.Dataset.FromString,
          response_serializer=anndb_dot_dataset__pb2.Dataset.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=anndb_dot_core__pb2.UUIDRequest.FromString,
          response_serializer=anndb_dot_core__pb2.EmptyMessage.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'anndb_pb.DatasetManager', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))


class DataManagerStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Insert = channel.unary_unary(
        '/anndb_pb.DataManager/Insert',
        request_serializer=anndb_dot_dataset__pb2.InsertRequest.SerializeToString,
        response_deserializer=anndb_dot_core__pb2.EmptyMessage.FromString,
        )
    self.Update = channel.unary_unary(
        '/anndb_pb.DataManager/Update',
        request_serializer=anndb_dot_dataset__pb2.UpdateRequest.SerializeToString,
        response_deserializer=anndb_dot_core__pb2.EmptyMessage.FromString,
        )
    self.Remove = channel.unary_unary(
        '/anndb_pb.DataManager/Remove',
        request_serializer=anndb_dot_dataset__pb2.RemoveRequest.SerializeToString,
        response_deserializer=anndb_dot_core__pb2.EmptyMessage.FromString,
        )
    self.BatchInsert = channel.unary_unary(
        '/anndb_pb.DataManager/BatchInsert',
        request_serializer=anndb_dot_dataset__pb2.BatchRequest.SerializeToString,
        response_deserializer=anndb_dot_dataset__pb2.BatchResponse.FromString,
        )
    self.BatchUpdate = channel.unary_unary(
        '/anndb_pb.DataManager/BatchUpdate',
        request_serializer=anndb_dot_dataset__pb2.BatchRequest.SerializeToString,
        response_deserializer=anndb_dot_dataset__pb2.BatchResponse.FromString,
        )
    self.BatchRemove = channel.unary_unary(
        '/anndb_pb.DataManager/BatchRemove',
        request_serializer=anndb_dot_dataset__pb2.BatchRequest.SerializeToString,
        response_deserializer=anndb_dot_dataset__pb2.BatchResponse.FromString,
        )
    self.PartitionBatchInsert = channel.unary_unary(
        '/anndb_pb.DataManager/PartitionBatchInsert',
        request_serializer=anndb_dot_dataset__pb2.PartitionBatchRequest.SerializeToString,
        response_deserializer=anndb_dot_dataset__pb2.BatchResponse.FromString,
        )
    self.PartitionBatchUpdate = channel.unary_unary(
        '/anndb_pb.DataManager/PartitionBatchUpdate',
        request_serializer=anndb_dot_dataset__pb2.PartitionBatchRequest.SerializeToString,
        response_deserializer=anndb_dot_dataset__pb2.BatchResponse.FromString,
        )
    self.PartitionBatchRemove = channel.unary_unary(
        '/anndb_pb.DataManager/PartitionBatchRemove',
        request_serializer=anndb_dot_dataset__pb2.PartitionBatchRequest.SerializeToString,
        response_deserializer=anndb_dot_dataset__pb2.BatchResponse.FromString,
        )


class DataManagerServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Insert(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Update(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Remove(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def BatchInsert(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def BatchUpdate(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def BatchRemove(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PartitionBatchInsert(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PartitionBatchUpdate(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PartitionBatchRemove(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_DataManagerServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Insert': grpc.unary_unary_rpc_method_handler(
          servicer.Insert,
          request_deserializer=anndb_dot_dataset__pb2.InsertRequest.FromString,
          response_serializer=anndb_dot_core__pb2.EmptyMessage.SerializeToString,
      ),
      'Update': grpc.unary_unary_rpc_method_handler(
          servicer.Update,
          request_deserializer=anndb_dot_dataset__pb2.UpdateRequest.FromString,
          response_serializer=anndb_dot_core__pb2.EmptyMessage.SerializeToString,
      ),
      'Remove': grpc.unary_unary_rpc_method_handler(
          servicer.Remove,
          request_deserializer=anndb_dot_dataset__pb2.RemoveRequest.FromString,
          response_serializer=anndb_dot_core__pb2.EmptyMessage.SerializeToString,
      ),
      'BatchInsert': grpc.unary_unary_rpc_method_handler(
          servicer.BatchInsert,
          request_deserializer=anndb_dot_dataset__pb2.BatchRequest.FromString,
          response_serializer=anndb_dot_dataset__pb2.BatchResponse.SerializeToString,
      ),
      'BatchUpdate': grpc.unary_unary_rpc_method_handler(
          servicer.BatchUpdate,
          request_deserializer=anndb_dot_dataset__pb2.BatchRequest.FromString,
          response_serializer=anndb_dot_dataset__pb2.BatchResponse.SerializeToString,
      ),
      'BatchRemove': grpc.unary_unary_rpc_method_handler(
          servicer.BatchRemove,
          request_deserializer=anndb_dot_dataset__pb2.BatchRequest.FromString,
          response_serializer=anndb_dot_dataset__pb2.BatchResponse.SerializeToString,
      ),
      'PartitionBatchInsert': grpc.unary_unary_rpc_method_handler(
          servicer.PartitionBatchInsert,
          request_deserializer=anndb_dot_dataset__pb2.PartitionBatchRequest.FromString,
          response_serializer=anndb_dot_dataset__pb2.BatchResponse.SerializeToString,
      ),
      'PartitionBatchUpdate': grpc.unary_unary_rpc_method_handler(
          servicer.PartitionBatchUpdate,
          request_deserializer=anndb_dot_dataset__pb2.PartitionBatchRequest.FromString,
          response_serializer=anndb_dot_dataset__pb2.BatchResponse.SerializeToString,
      ),
      'PartitionBatchRemove': grpc.unary_unary_rpc_method_handler(
          servicer.PartitionBatchRemove,
          request_deserializer=anndb_dot_dataset__pb2.PartitionBatchRequest.FromString,
          response_serializer=anndb_dot_dataset__pb2.BatchResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'anndb_pb.DataManager', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
