# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: anndb/cluster.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from anndb import core_pb2 as anndb_dot_core__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='anndb/cluster.proto',
  package='anndb_pb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x13\x61nndb/cluster.proto\x12\x08\x61nndb_pb\x1a\x10\x61nndb/core.proto\"#\n\x04Node\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t2\xa8\x01\n\x0cNodesManager\x12\x35\n\tListNodes\x12\x16.anndb_pb.EmptyMessage\x1a\x0e.anndb_pb.Node0\x01\x12+\n\x07\x41\x64\x64Node\x12\x0e.anndb_pb.Node\x1a\x0e.anndb_pb.Node0\x01\x12\x34\n\nRemoveNode\x12\x0e.anndb_pb.Node\x1a\x16.anndb_pb.EmptyMessageb\x06proto3')
  ,
  dependencies=[anndb_dot_core__pb2.DESCRIPTOR,])




_NODE = _descriptor.Descriptor(
  name='Node',
  full_name='anndb_pb.Node',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='anndb_pb.Node.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='address', full_name='anndb_pb.Node.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51,
  serialized_end=86,
)

DESCRIPTOR.message_types_by_name['Node'] = _NODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), dict(
  DESCRIPTOR = _NODE,
  __module__ = 'anndb.cluster_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.Node)
  ))
_sym_db.RegisterMessage(Node)



_NODESMANAGER = _descriptor.ServiceDescriptor(
  name='NodesManager',
  full_name='anndb_pb.NodesManager',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=89,
  serialized_end=257,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListNodes',
    full_name='anndb_pb.NodesManager.ListNodes',
    index=0,
    containing_service=None,
    input_type=anndb_dot_core__pb2._EMPTYMESSAGE,
    output_type=_NODE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddNode',
    full_name='anndb_pb.NodesManager.AddNode',
    index=1,
    containing_service=None,
    input_type=_NODE,
    output_type=_NODE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveNode',
    full_name='anndb_pb.NodesManager.RemoveNode',
    index=2,
    containing_service=None,
    input_type=_NODE,
    output_type=anndb_dot_core__pb2._EMPTYMESSAGE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_NODESMANAGER)

DESCRIPTOR.services_by_name['NodesManager'] = _NODESMANAGER

# @@protoc_insertion_point(module_scope)
