# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: anndb/dataset.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from anndb import core_pb2 as anndb_dot_core__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='anndb/dataset.proto',
  package='anndb_pb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x13\x61nndb/dataset.proto\x12\x08\x61nndb_pb\x1a\x10\x61nndb/core.proto\"\xa8\x01\n\rInsertRequest\x12\x12\n\ndataset_id\x18\x01 \x01(\x0c\x12\n\n\x02id\x18\x02 \x01(\x04\x12\r\n\x05value\x18\x03 \x03(\x02\x12\x37\n\x08metadata\x18\x04 \x03(\x0b\x32%.anndb_pb.InsertRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa8\x01\n\rUpdateRequest\x12\x12\n\ndataset_id\x18\x01 \x01(\x0c\x12\n\n\x02id\x18\x02 \x01(\x04\x12\r\n\x05value\x18\x03 \x03(\x02\x12\x37\n\x08metadata\x18\x04 \x03(\x0b\x32%.anndb_pb.UpdateRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"/\n\rRemoveRequest\x12\x12\n\ndataset_id\x18\x01 \x01(\x0c\x12\n\n\x02id\x18\x02 \x01(\x04\"\x9b\x01\n\tBatchItem\x12\n\n\x02id\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x03(\x02\x12\x33\n\x08metadata\x18\x03 \x03(\x0b\x32!.anndb_pb.BatchItem.MetadataEntry\x12\r\n\x05level\x18\x04 \x01(\x05\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"F\n\x0c\x42\x61tchRequest\x12\x12\n\ndataset_id\x18\x01 \x01(\x0c\x12\"\n\x05items\x18\x02 \x03(\x0b\x32\x13.anndb_pb.BatchItem\"e\n\x15PartitionBatchRequest\x12\x12\n\ndataset_id\x18\x01 \x01(\x0c\x12\x14\n\x0cpartition_id\x18\x02 \x01(\x0c\x12\"\n\x05items\x18\x03 \x03(\x0b\x32\x13.anndb_pb.BatchItem\"s\n\rBatchResponse\x12\x33\n\x06\x65rrors\x18\x01 \x03(\x0b\x32#.anndb_pb.BatchResponse.ErrorsEntry\x1a-\n\x0b\x45rrorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa6\x01\n\x07\x44\x61taset\x12\n\n\x02id\x18\x01 \x01(\x0c\x12\x11\n\tdimension\x18\x02 \x01(\r\x12\x1e\n\x05space\x18\x03 \x01(\x0e\x32\x0f.anndb_pb.Space\x12\x17\n\x0fpartition_count\x18\x04 \x01(\r\x12\x1a\n\x12replication_factor\x18\x05 \x01(\r\x12\'\n\npartitions\x18\x06 \x03(\x0b\x32\x13.anndb_pb.Partition\")\n\tPartition\x12\n\n\x02id\x18\x01 \x01(\x0c\x12\x10\n\x08node_ids\x18\x02 \x03(\x04\"o\n\x14\x44\x61tasetManagerChange\x12\x30\n\x04type\x18\x01 \x01(\x0e\x32\".anndb_pb.DatasetManagerChangeType\x12\x17\n\x0fnotification_id\x18\x02 \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"\x91\x01\n\x1b\x44\x61tasetPartitionNodesChange\x12\x37\n\x04type\x18\x01 \x01(\x0e\x32).anndb_pb.DatasetPartitionNodesChangeType\x12\x12\n\ndataset_id\x18\x02 \x01(\x0c\x12\x14\n\x0cpartition_id\x18\x03 \x01(\x0c\x12\x0f\n\x07node_id\x18\x04 \x01(\x04\"\x97\x02\n\x0fPartitionChange\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.anndb_pb.PartitionChangeType\x12\x17\n\x0fnotification_id\x18\x02 \x01(\x0c\x12\n\n\x02id\x18\x03 \x01(\x04\x12\r\n\x05value\x18\x04 \x03(\x02\x12\x39\n\x08metadata\x18\x05 \x03(\x0b\x32\'.anndb_pb.PartitionChange.MetadataEntry\x12\r\n\x05level\x18\x06 \x01(\x05\x12(\n\x0b\x62\x61tch_items\x18\x07 \x03(\x0b\x32\x13.anndb_pb.BatchItem\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"=\n\x16\x44\x61tasetManagerSnapshot\x12#\n\x08\x64\x61tasets\x18\x01 \x03(\x0b\x32\x11.anndb_pb.Dataset*1\n\x05Space\x12\r\n\tEuclidean\x10\x00\x12\r\n\tManhattan\x10\x01\x12\n\n\x06\x43osine\x10\x02*\x84\x01\n\x18\x44\x61tasetManagerChangeType\x12\x1f\n\x1b\x44\x61tasetManagerCreateDataset\x10\x00\x12\x1f\n\x1b\x44\x61tasetManagerDeleteDataset\x10\x01\x12&\n\"DatasetManagerUpdatePartitionNodes\x10\x02*t\n\x1f\x44\x61tasetPartitionNodesChangeType\x12&\n\"DatasetPartitionNodesChangeAddNode\x10\x00\x12)\n%DatasetPartitionNodesChangeRemoveNode\x10\x01*\xe4\x01\n\x13PartitionChangeType\x12\x1e\n\x1aPartitionChangeInsertValue\x10\x00\x12\x1e\n\x1aPartitionChangeUpdateValue\x10\x01\x12\x1e\n\x1aPartitionChangeDeleteValue\x10\x02\x12#\n\x1fPartitionChangeBatchInsertValue\x10\x03\x12#\n\x1fPartitionChangeBatchUpdateValue\x10\x04\x12#\n\x1fPartitionChangeBatchDeleteValue\x10\x05\x32\xdf\x01\n\x0e\x44\x61tasetManager\x12\x33\n\x04List\x12\x16.anndb_pb.EmptyMessage\x1a\x11.anndb_pb.Dataset0\x01\x12/\n\x03Get\x12\x15.anndb_pb.UUIDRequest\x1a\x11.anndb_pb.Dataset\x12.\n\x06\x43reate\x12\x11.anndb_pb.Dataset\x1a\x11.anndb_pb.Dataset\x12\x37\n\x06\x44\x65lete\x12\x15.anndb_pb.UUIDRequest\x1a\x16.anndb_pb.EmptyMessage2\xf4\x04\n\x0b\x44\x61taManager\x12\x39\n\x06Insert\x12\x17.anndb_pb.InsertRequest\x1a\x16.anndb_pb.EmptyMessage\x12\x39\n\x06Update\x12\x17.anndb_pb.UpdateRequest\x1a\x16.anndb_pb.EmptyMessage\x12\x39\n\x06Remove\x12\x17.anndb_pb.RemoveRequest\x1a\x16.anndb_pb.EmptyMessage\x12>\n\x0b\x42\x61tchInsert\x12\x16.anndb_pb.BatchRequest\x1a\x17.anndb_pb.BatchResponse\x12>\n\x0b\x42\x61tchUpdate\x12\x16.anndb_pb.BatchRequest\x1a\x17.anndb_pb.BatchResponse\x12>\n\x0b\x42\x61tchRemove\x12\x16.anndb_pb.BatchRequest\x1a\x17.anndb_pb.BatchResponse\x12P\n\x14PartitionBatchInsert\x12\x1f.anndb_pb.PartitionBatchRequest\x1a\x17.anndb_pb.BatchResponse\x12P\n\x14PartitionBatchUpdate\x12\x1f.anndb_pb.PartitionBatchRequest\x1a\x17.anndb_pb.BatchResponse\x12P\n\x14PartitionBatchRemove\x12\x1f.anndb_pb.PartitionBatchRequest\x1a\x17.anndb_pb.BatchResponseb\x06proto3')
  ,
  dependencies=[anndb_dot_core__pb2.DESCRIPTOR,])

_SPACE = _descriptor.EnumDescriptor(
  name='Space',
  full_name='anndb_pb.Space',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Euclidean', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Manhattan', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Cosine', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1710,
  serialized_end=1759,
)
_sym_db.RegisterEnumDescriptor(_SPACE)

Space = enum_type_wrapper.EnumTypeWrapper(_SPACE)
_DATASETMANAGERCHANGETYPE = _descriptor.EnumDescriptor(
  name='DatasetManagerChangeType',
  full_name='anndb_pb.DatasetManagerChangeType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DatasetManagerCreateDataset', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DatasetManagerDeleteDataset', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DatasetManagerUpdatePartitionNodes', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1762,
  serialized_end=1894,
)
_sym_db.RegisterEnumDescriptor(_DATASETMANAGERCHANGETYPE)

DatasetManagerChangeType = enum_type_wrapper.EnumTypeWrapper(_DATASETMANAGERCHANGETYPE)
_DATASETPARTITIONNODESCHANGETYPE = _descriptor.EnumDescriptor(
  name='DatasetPartitionNodesChangeType',
  full_name='anndb_pb.DatasetPartitionNodesChangeType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DatasetPartitionNodesChangeAddNode', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DatasetPartitionNodesChangeRemoveNode', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1896,
  serialized_end=2012,
)
_sym_db.RegisterEnumDescriptor(_DATASETPARTITIONNODESCHANGETYPE)

DatasetPartitionNodesChangeType = enum_type_wrapper.EnumTypeWrapper(_DATASETPARTITIONNODESCHANGETYPE)
_PARTITIONCHANGETYPE = _descriptor.EnumDescriptor(
  name='PartitionChangeType',
  full_name='anndb_pb.PartitionChangeType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PartitionChangeInsertValue', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PartitionChangeUpdateValue', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PartitionChangeDeleteValue', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PartitionChangeBatchInsertValue', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PartitionChangeBatchUpdateValue', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PartitionChangeBatchDeleteValue', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2015,
  serialized_end=2243,
)
_sym_db.RegisterEnumDescriptor(_PARTITIONCHANGETYPE)

PartitionChangeType = enum_type_wrapper.EnumTypeWrapper(_PARTITIONCHANGETYPE)
Euclidean = 0
Manhattan = 1
Cosine = 2
DatasetManagerCreateDataset = 0
DatasetManagerDeleteDataset = 1
DatasetManagerUpdatePartitionNodes = 2
DatasetPartitionNodesChangeAddNode = 0
DatasetPartitionNodesChangeRemoveNode = 1
PartitionChangeInsertValue = 0
PartitionChangeUpdateValue = 1
PartitionChangeDeleteValue = 2
PartitionChangeBatchInsertValue = 3
PartitionChangeBatchUpdateValue = 4
PartitionChangeBatchDeleteValue = 5



_INSERTREQUEST_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='anndb_pb.InsertRequest.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='anndb_pb.InsertRequest.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='anndb_pb.InsertRequest.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=173,
  serialized_end=220,
)

_INSERTREQUEST = _descriptor.Descriptor(
  name='InsertRequest',
  full_name='anndb_pb.InsertRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='anndb_pb.InsertRequest.dataset_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='anndb_pb.InsertRequest.id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='anndb_pb.InsertRequest.value', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='anndb_pb.InsertRequest.metadata', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INSERTREQUEST_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=220,
)


_UPDATEREQUEST_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='anndb_pb.UpdateRequest.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='anndb_pb.UpdateRequest.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='anndb_pb.UpdateRequest.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=173,
  serialized_end=220,
)

_UPDATEREQUEST = _descriptor.Descriptor(
  name='UpdateRequest',
  full_name='anndb_pb.UpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='anndb_pb.UpdateRequest.dataset_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='anndb_pb.UpdateRequest.id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='anndb_pb.UpdateRequest.value', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='anndb_pb.UpdateRequest.metadata', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEREQUEST_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=223,
  serialized_end=391,
)


_REMOVEREQUEST = _descriptor.Descriptor(
  name='RemoveRequest',
  full_name='anndb_pb.RemoveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='anndb_pb.RemoveRequest.dataset_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='anndb_pb.RemoveRequest.id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=440,
)


_BATCHITEM_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='anndb_pb.BatchItem.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='anndb_pb.BatchItem.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='anndb_pb.BatchItem.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=173,
  serialized_end=220,
)

_BATCHITEM = _descriptor.Descriptor(
  name='BatchItem',
  full_name='anndb_pb.BatchItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='anndb_pb.BatchItem.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='anndb_pb.BatchItem.value', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='anndb_pb.BatchItem.metadata', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level', full_name='anndb_pb.BatchItem.level', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_BATCHITEM_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=443,
  serialized_end=598,
)


_BATCHREQUEST = _descriptor.Descriptor(
  name='BatchRequest',
  full_name='anndb_pb.BatchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='anndb_pb.BatchRequest.dataset_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='items', full_name='anndb_pb.BatchRequest.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=600,
  serialized_end=670,
)


_PARTITIONBATCHREQUEST = _descriptor.Descriptor(
  name='PartitionBatchRequest',
  full_name='anndb_pb.PartitionBatchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='anndb_pb.PartitionBatchRequest.dataset_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_id', full_name='anndb_pb.PartitionBatchRequest.partition_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='items', full_name='anndb_pb.PartitionBatchRequest.items', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=672,
  serialized_end=773,
)


_BATCHRESPONSE_ERRORSENTRY = _descriptor.Descriptor(
  name='ErrorsEntry',
  full_name='anndb_pb.BatchResponse.ErrorsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='anndb_pb.BatchResponse.ErrorsEntry.key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='anndb_pb.BatchResponse.ErrorsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=845,
  serialized_end=890,
)

_BATCHRESPONSE = _descriptor.Descriptor(
  name='BatchResponse',
  full_name='anndb_pb.BatchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='errors', full_name='anndb_pb.BatchResponse.errors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_BATCHRESPONSE_ERRORSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=775,
  serialized_end=890,
)


_DATASET = _descriptor.Descriptor(
  name='Dataset',
  full_name='anndb_pb.Dataset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='anndb_pb.Dataset.id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dimension', full_name='anndb_pb.Dataset.dimension', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='space', full_name='anndb_pb.Dataset.space', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_count', full_name='anndb_pb.Dataset.partition_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replication_factor', full_name='anndb_pb.Dataset.replication_factor', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partitions', full_name='anndb_pb.Dataset.partitions', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=893,
  serialized_end=1059,
)


_PARTITION = _descriptor.Descriptor(
  name='Partition',
  full_name='anndb_pb.Partition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='anndb_pb.Partition.id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_ids', full_name='anndb_pb.Partition.node_ids', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1061,
  serialized_end=1102,
)


_DATASETMANAGERCHANGE = _descriptor.Descriptor(
  name='DatasetManagerChange',
  full_name='anndb_pb.DatasetManagerChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='anndb_pb.DatasetManagerChange.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notification_id', full_name='anndb_pb.DatasetManagerChange.notification_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='anndb_pb.DatasetManagerChange.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1104,
  serialized_end=1215,
)


_DATASETPARTITIONNODESCHANGE = _descriptor.Descriptor(
  name='DatasetPartitionNodesChange',
  full_name='anndb_pb.DatasetPartitionNodesChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='anndb_pb.DatasetPartitionNodesChange.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='anndb_pb.DatasetPartitionNodesChange.dataset_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_id', full_name='anndb_pb.DatasetPartitionNodesChange.partition_id', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='anndb_pb.DatasetPartitionNodesChange.node_id', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1218,
  serialized_end=1363,
)


_PARTITIONCHANGE_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='anndb_pb.PartitionChange.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='anndb_pb.PartitionChange.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='anndb_pb.PartitionChange.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=173,
  serialized_end=220,
)

_PARTITIONCHANGE = _descriptor.Descriptor(
  name='PartitionChange',
  full_name='anndb_pb.PartitionChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='anndb_pb.PartitionChange.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notification_id', full_name='anndb_pb.PartitionChange.notification_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='anndb_pb.PartitionChange.id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='anndb_pb.PartitionChange.value', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='anndb_pb.PartitionChange.metadata', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level', full_name='anndb_pb.PartitionChange.level', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='batch_items', full_name='anndb_pb.PartitionChange.batch_items', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PARTITIONCHANGE_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1366,
  serialized_end=1645,
)


_DATASETMANAGERSNAPSHOT = _descriptor.Descriptor(
  name='DatasetManagerSnapshot',
  full_name='anndb_pb.DatasetManagerSnapshot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='datasets', full_name='anndb_pb.DatasetManagerSnapshot.datasets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1647,
  serialized_end=1708,
)

_INSERTREQUEST_METADATAENTRY.containing_type = _INSERTREQUEST
_INSERTREQUEST.fields_by_name['metadata'].message_type = _INSERTREQUEST_METADATAENTRY
_UPDATEREQUEST_METADATAENTRY.containing_type = _UPDATEREQUEST
_UPDATEREQUEST.fields_by_name['metadata'].message_type = _UPDATEREQUEST_METADATAENTRY
_BATCHITEM_METADATAENTRY.containing_type = _BATCHITEM
_BATCHITEM.fields_by_name['metadata'].message_type = _BATCHITEM_METADATAENTRY
_BATCHREQUEST.fields_by_name['items'].message_type = _BATCHITEM
_PARTITIONBATCHREQUEST.fields_by_name['items'].message_type = _BATCHITEM
_BATCHRESPONSE_ERRORSENTRY.containing_type = _BATCHRESPONSE
_BATCHRESPONSE.fields_by_name['errors'].message_type = _BATCHRESPONSE_ERRORSENTRY
_DATASET.fields_by_name['space'].enum_type = _SPACE
_DATASET.fields_by_name['partitions'].message_type = _PARTITION
_DATASETMANAGERCHANGE.fields_by_name['type'].enum_type = _DATASETMANAGERCHANGETYPE
_DATASETPARTITIONNODESCHANGE.fields_by_name['type'].enum_type = _DATASETPARTITIONNODESCHANGETYPE
_PARTITIONCHANGE_METADATAENTRY.containing_type = _PARTITIONCHANGE
_PARTITIONCHANGE.fields_by_name['type'].enum_type = _PARTITIONCHANGETYPE
_PARTITIONCHANGE.fields_by_name['metadata'].message_type = _PARTITIONCHANGE_METADATAENTRY
_PARTITIONCHANGE.fields_by_name['batch_items'].message_type = _BATCHITEM
_DATASETMANAGERSNAPSHOT.fields_by_name['datasets'].message_type = _DATASET
DESCRIPTOR.message_types_by_name['InsertRequest'] = _INSERTREQUEST
DESCRIPTOR.message_types_by_name['UpdateRequest'] = _UPDATEREQUEST
DESCRIPTOR.message_types_by_name['RemoveRequest'] = _REMOVEREQUEST
DESCRIPTOR.message_types_by_name['BatchItem'] = _BATCHITEM
DESCRIPTOR.message_types_by_name['BatchRequest'] = _BATCHREQUEST
DESCRIPTOR.message_types_by_name['PartitionBatchRequest'] = _PARTITIONBATCHREQUEST
DESCRIPTOR.message_types_by_name['BatchResponse'] = _BATCHRESPONSE
DESCRIPTOR.message_types_by_name['Dataset'] = _DATASET
DESCRIPTOR.message_types_by_name['Partition'] = _PARTITION
DESCRIPTOR.message_types_by_name['DatasetManagerChange'] = _DATASETMANAGERCHANGE
DESCRIPTOR.message_types_by_name['DatasetPartitionNodesChange'] = _DATASETPARTITIONNODESCHANGE
DESCRIPTOR.message_types_by_name['PartitionChange'] = _PARTITIONCHANGE
DESCRIPTOR.message_types_by_name['DatasetManagerSnapshot'] = _DATASETMANAGERSNAPSHOT
DESCRIPTOR.enum_types_by_name['Space'] = _SPACE
DESCRIPTOR.enum_types_by_name['DatasetManagerChangeType'] = _DATASETMANAGERCHANGETYPE
DESCRIPTOR.enum_types_by_name['DatasetPartitionNodesChangeType'] = _DATASETPARTITIONNODESCHANGETYPE
DESCRIPTOR.enum_types_by_name['PartitionChangeType'] = _PARTITIONCHANGETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InsertRequest = _reflection.GeneratedProtocolMessageType('InsertRequest', (_message.Message,), dict(

  MetadataEntry = _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), dict(
    DESCRIPTOR = _INSERTREQUEST_METADATAENTRY,
    __module__ = 'anndb.dataset_pb2'
    # @@protoc_insertion_point(class_scope:anndb_pb.InsertRequest.MetadataEntry)
    ))
  ,
  DESCRIPTOR = _INSERTREQUEST,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.InsertRequest)
  ))
_sym_db.RegisterMessage(InsertRequest)
_sym_db.RegisterMessage(InsertRequest.MetadataEntry)

UpdateRequest = _reflection.GeneratedProtocolMessageType('UpdateRequest', (_message.Message,), dict(

  MetadataEntry = _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), dict(
    DESCRIPTOR = _UPDATEREQUEST_METADATAENTRY,
    __module__ = 'anndb.dataset_pb2'
    # @@protoc_insertion_point(class_scope:anndb_pb.UpdateRequest.MetadataEntry)
    ))
  ,
  DESCRIPTOR = _UPDATEREQUEST,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.UpdateRequest)
  ))
_sym_db.RegisterMessage(UpdateRequest)
_sym_db.RegisterMessage(UpdateRequest.MetadataEntry)

RemoveRequest = _reflection.GeneratedProtocolMessageType('RemoveRequest', (_message.Message,), dict(
  DESCRIPTOR = _REMOVEREQUEST,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.RemoveRequest)
  ))
_sym_db.RegisterMessage(RemoveRequest)

BatchItem = _reflection.GeneratedProtocolMessageType('BatchItem', (_message.Message,), dict(

  MetadataEntry = _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), dict(
    DESCRIPTOR = _BATCHITEM_METADATAENTRY,
    __module__ = 'anndb.dataset_pb2'
    # @@protoc_insertion_point(class_scope:anndb_pb.BatchItem.MetadataEntry)
    ))
  ,
  DESCRIPTOR = _BATCHITEM,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.BatchItem)
  ))
_sym_db.RegisterMessage(BatchItem)
_sym_db.RegisterMessage(BatchItem.MetadataEntry)

BatchRequest = _reflection.GeneratedProtocolMessageType('BatchRequest', (_message.Message,), dict(
  DESCRIPTOR = _BATCHREQUEST,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.BatchRequest)
  ))
_sym_db.RegisterMessage(BatchRequest)

PartitionBatchRequest = _reflection.GeneratedProtocolMessageType('PartitionBatchRequest', (_message.Message,), dict(
  DESCRIPTOR = _PARTITIONBATCHREQUEST,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.PartitionBatchRequest)
  ))
_sym_db.RegisterMessage(PartitionBatchRequest)

BatchResponse = _reflection.GeneratedProtocolMessageType('BatchResponse', (_message.Message,), dict(

  ErrorsEntry = _reflection.GeneratedProtocolMessageType('ErrorsEntry', (_message.Message,), dict(
    DESCRIPTOR = _BATCHRESPONSE_ERRORSENTRY,
    __module__ = 'anndb.dataset_pb2'
    # @@protoc_insertion_point(class_scope:anndb_pb.BatchResponse.ErrorsEntry)
    ))
  ,
  DESCRIPTOR = _BATCHRESPONSE,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.BatchResponse)
  ))
_sym_db.RegisterMessage(BatchResponse)
_sym_db.RegisterMessage(BatchResponse.ErrorsEntry)

Dataset = _reflection.GeneratedProtocolMessageType('Dataset', (_message.Message,), dict(
  DESCRIPTOR = _DATASET,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.Dataset)
  ))
_sym_db.RegisterMessage(Dataset)

Partition = _reflection.GeneratedProtocolMessageType('Partition', (_message.Message,), dict(
  DESCRIPTOR = _PARTITION,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.Partition)
  ))
_sym_db.RegisterMessage(Partition)

DatasetManagerChange = _reflection.GeneratedProtocolMessageType('DatasetManagerChange', (_message.Message,), dict(
  DESCRIPTOR = _DATASETMANAGERCHANGE,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.DatasetManagerChange)
  ))
_sym_db.RegisterMessage(DatasetManagerChange)

DatasetPartitionNodesChange = _reflection.GeneratedProtocolMessageType('DatasetPartitionNodesChange', (_message.Message,), dict(
  DESCRIPTOR = _DATASETPARTITIONNODESCHANGE,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.DatasetPartitionNodesChange)
  ))
_sym_db.RegisterMessage(DatasetPartitionNodesChange)

PartitionChange = _reflection.GeneratedProtocolMessageType('PartitionChange', (_message.Message,), dict(

  MetadataEntry = _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), dict(
    DESCRIPTOR = _PARTITIONCHANGE_METADATAENTRY,
    __module__ = 'anndb.dataset_pb2'
    # @@protoc_insertion_point(class_scope:anndb_pb.PartitionChange.MetadataEntry)
    ))
  ,
  DESCRIPTOR = _PARTITIONCHANGE,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.PartitionChange)
  ))
_sym_db.RegisterMessage(PartitionChange)
_sym_db.RegisterMessage(PartitionChange.MetadataEntry)

DatasetManagerSnapshot = _reflection.GeneratedProtocolMessageType('DatasetManagerSnapshot', (_message.Message,), dict(
  DESCRIPTOR = _DATASETMANAGERSNAPSHOT,
  __module__ = 'anndb.dataset_pb2'
  # @@protoc_insertion_point(class_scope:anndb_pb.DatasetManagerSnapshot)
  ))
_sym_db.RegisterMessage(DatasetManagerSnapshot)


_INSERTREQUEST_METADATAENTRY._options = None
_UPDATEREQUEST_METADATAENTRY._options = None
_BATCHITEM_METADATAENTRY._options = None
_BATCHRESPONSE_ERRORSENTRY._options = None
_PARTITIONCHANGE_METADATAENTRY._options = None

_DATASETMANAGER = _descriptor.ServiceDescriptor(
  name='DatasetManager',
  full_name='anndb_pb.DatasetManager',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2246,
  serialized_end=2469,
  methods=[
  _descriptor.MethodDescriptor(
    name='List',
    full_name='anndb_pb.DatasetManager.List',
    index=0,
    containing_service=None,
    input_type=anndb_dot_core__pb2._EMPTYMESSAGE,
    output_type=_DATASET,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='anndb_pb.DatasetManager.Get',
    index=1,
    containing_service=None,
    input_type=anndb_dot_core__pb2._UUIDREQUEST,
    output_type=_DATASET,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='anndb_pb.DatasetManager.Create',
    index=2,
    containing_service=None,
    input_type=_DATASET,
    output_type=_DATASET,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='anndb_pb.DatasetManager.Delete',
    index=3,
    containing_service=None,
    input_type=anndb_dot_core__pb2._UUIDREQUEST,
    output_type=anndb_dot_core__pb2._EMPTYMESSAGE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATASETMANAGER)

DESCRIPTOR.services_by_name['DatasetManager'] = _DATASETMANAGER


_DATAMANAGER = _descriptor.ServiceDescriptor(
  name='DataManager',
  full_name='anndb_pb.DataManager',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  serialized_start=2472,
  serialized_end=3100,
  methods=[
  _descriptor.MethodDescriptor(
    name='Insert',
    full_name='anndb_pb.DataManager.Insert',
    index=0,
    containing_service=None,
    input_type=_INSERTREQUEST,
    output_type=anndb_dot_core__pb2._EMPTYMESSAGE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='anndb_pb.DataManager.Update',
    index=1,
    containing_service=None,
    input_type=_UPDATEREQUEST,
    output_type=anndb_dot_core__pb2._EMPTYMESSAGE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Remove',
    full_name='anndb_pb.DataManager.Remove',
    index=2,
    containing_service=None,
    input_type=_REMOVEREQUEST,
    output_type=anndb_dot_core__pb2._EMPTYMESSAGE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='BatchInsert',
    full_name='anndb_pb.DataManager.BatchInsert',
    index=3,
    containing_service=None,
    input_type=_BATCHREQUEST,
    output_type=_BATCHRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='BatchUpdate',
    full_name='anndb_pb.DataManager.BatchUpdate',
    index=4,
    containing_service=None,
    input_type=_BATCHREQUEST,
    output_type=_BATCHRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='BatchRemove',
    full_name='anndb_pb.DataManager.BatchRemove',
    index=5,
    containing_service=None,
    input_type=_BATCHREQUEST,
    output_type=_BATCHRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PartitionBatchInsert',
    full_name='anndb_pb.DataManager.PartitionBatchInsert',
    index=6,
    containing_service=None,
    input_type=_PARTITIONBATCHREQUEST,
    output_type=_BATCHRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PartitionBatchUpdate',
    full_name='anndb_pb.DataManager.PartitionBatchUpdate',
    index=7,
    containing_service=None,
    input_type=_PARTITIONBATCHREQUEST,
    output_type=_BATCHRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PartitionBatchRemove',
    full_name='anndb_pb.DataManager.PartitionBatchRemove',
    index=8,
    containing_service=None,
    input_type=_PARTITIONBATCHREQUEST,
    output_type=_BATCHRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATAMANAGER)

DESCRIPTOR.services_by_name['DataManager'] = _DATAMANAGER

# @@protoc_insertion_point(module_scope)
